# Notebook Tutorials

📜 *Extensive user guide, mostly based on step-by-step tutorials ...*

All tutorials are written in jupyter notebooks, that can be :

- read using the [online documentation](https://marge-3d-solver.readthedocs.io/en/latest/notebooks.html)
- downloaded from the [notebook folder](https://github.com/CompMath-TUHH/MaRGE_3D_solver/tree/main/docs/notebooks) and played with

📋 **Table of content**

```{eval-rst}

.. toctree::
    :maxdepth: 1
    :glob:

    notebooks/*